﻿#include "SpringSim.as"
//
// Add rendering options buttons
//
ss = new SpringSim(this, 3, 0.25, 0.01);
ss.simFloor = 300;
ss.setRenderFlags(SpringSim.RENDER_SPRINGS | SpringSim.RENDER_DOTS);
myDots = [];
title_txt.autoSize = true;

XMLnode.prototype.loadSoda = function()
{
	if (this.nodeName == 'settings') {
		if (this.attributes['gravitydirection'] == 'up') {
			ss.setGravity(-ss.gravK);
		}
		if (this.attributes['wavedirection'] == 'forward') {
		}
		if (this.attributes['autoreverse'] == 'on')
			ss.setAutoReverse(true);
		else
			ss.setAutoReverse(false);
	}
	if (this.nodeName == 'name')
	{
		title_txt.text = this.firstChild.nodeValue;
	}
	if (this.nodeName == 'gridscale') 
	{
		tw = Number(this.attributes['cellwidth']);
		th = Number(this.attributes['cellheight']);
		ox = Number(this.attributes['originx']);
		oy = Number(this.attributes['originy']);
	}
	if (this.nodeName == 'environment') {
		if (this.attributes['gravity'])
			ss.setGravity(Number(this.attributes['gravity']));
		if (this.attributes['friction'])
			ss.setFriction(Number(this.attributes['friction']));
		if (this.attributes['springyness'])
			ss.setStiffness(Number(this.attributes['springyness']));
	}
	else if (this.nodeName == 'poly') {
		var clr = this.attributes['color'];
		if (clr.charAt(0) == '#')
			clr = Number('0x' + clr.substr(1));
		var ptNames = this.attributes['points'].split(',');
		var curvy = Number(this.attributes['curvy']);
		var pts = [];
		for (var i = 0; i < ptNames.length; ++i) 
		{
			pts.push(_root[ptNames[i]]);
		}
		ss.addPolygon(pts,clr,curvy);
	}
	else if (this.nodeName == 'collisions') {
		if (this.attributes['surface_friction'])
			ss.setFloorRoughness(Number(this.attributes['surface_friction']));
	}
	else if (this.nodeName == 'wave') {
		var amp = Number(this.attributes['amplitude']);
		var phase = Number(this.attributes['phase'])*Math.PI*2;
		var speed = Number(this.attributes['speed']);
		ss.setWave(amp,phase,speed);
	}
	else if (this.nodeName == 'mass') {
		// id,x,y,vx,vy
		var id = this.attributes['id'];
		var mc = _root.createEmptyMovieClip(id, _root.layerNbr++);
		myDots.push(mc);
		mc._x = ox+tw*Number(this.attributes['x']);
		mc._y = oy+th*Number(this.attributes['y']);
		mc.vx = Number(this.attributes['vx']);
		mc.vy = Number(this.attributes['vx']);
		var fixed = (Number(this.attributes['fixed']) == 1);
		mc.setDotProps(fixed, true);
		mc.drawDot();
	}
	else if (this.nodeName == 'spring' || this.nodeName == 'muscle') {
		// id,x,y,vx,vy
		var a = this.attributes['a'];
		var b = this.attributes['b'];
		var restLen = this.attributes['restlength'];
		var amp = Number(this.attributes['amplitude']);
		var phase = Number(this.attributes['phase'])*Math.PI*2;

		var spr = ss.addSpring(_root[a], _root[b]);
		
		if (restLen != undefined)
			spr.restLen = restLen;
		if (amp != undefined && phase != undefined)
			spr.setMuscle(amp,phase);
	}
	if (this.hasChildNodes()) {
		this.firstChild.loadSoda();
	}
	if (this.nextSibling != undefined) {
		this.nextSibling.loadSoda();
	}
}

var myxml = new XML();

myxml.onLoad = function()
{
	_root.layerNbr = 100;
	ox = 0;
	oy = 200;
	tw = 1;
	th = -1;
	ss.reset();
	for (var i = myDots.length-1; i >= 0; --i) {
		myDots[i].removeMovieClip();
	}
	myDots = [];
	// trace("doctype = " + this.docTypeDecl);
	this.loadSoda();
	setupUI();
	
}

models = ["daintywalker.xml", "puppetpete.xml", "lamp.xml", "jello.xml","discodan.xml"];
curModel = 0;

myxml.load(models[curModel]);
// myxml.load("lamp.xml");
curRS = 0;	// render style

#include "jbumUI.as"     
SW = Stage.width;
SH = Stage.height;

function loadNextModel()
{
	curModel = (curModel+1) % models.length;
	myxml.load(models[curModel]);
	curRS = 0;
}

function setupUI()
{
	btn_showpolys.setupToggleButton('show polys', false, function(t) { 
		curRS = !curRS;
		ss.setRenderFlags(curRS? (SpringSim.RENDER_DOTS | SpringSim.RENDER_POLYS) : (SpringSim.RENDER_SPRINGS | SpringSim.RENDER_DOTS)); 
		} 
	);
	btn_next.setupButton('next model', loadNextModel);

	slider1_mc.setupSlider('gravity',-2,2, ss.gravK,function(t) { ss.setGravity(t); } );
	slider2_mc.setupSlider('ground friction',0,1, 1-ss.floorDamping,function(t) { ss.setFloorRoughness(t); } );
	slider3_mc.setupSlider('wave speed',-.03,.03, ss.waveSpeed,function(t) { ss.waveSpeed = t; } );
}